@@ -135,26 +135,33 @@ assessments <- function(assessment_unit_id = NULL,
 
   ##setup file cache
   path = "attains-public/api/assessments"
-  assessments_cache$mkdir()
+  if(isTRUE(rATTAINSenv$cache_downloads)){
+    assessments_cache$mkdir()
 
-  ## check if current results have been cached
-  file_cache_name <- file_key(arg_list = args,
-                              name = "assessments.json")
-  file_path_name <- fs::path(assessments_cache$cache_path_get(),
-                             file_cache_name)
+    ## check if current results have been cached
+    file_cache_name <- file_key(arg_list = args,
+                                name = "assessments.json")
+    file_path_name <- fs::path(assessments_cache$cache_path_get(),
+                               file_cache_name)
 
-  if(file.exists(file_path_name)) {
-    message(paste0("reading cached file from: ", file_path_name))
-    content <- readLines(file_path_name, warn = FALSE)
-  }
-
-  ## download data
-  else{
+    if(file.exists(file_path_name)) {
+      message(paste0("reading cached file from: ", file_path_name))
+      content <- readLines(file_path_name, warn = FALSE)
+    } else {
+      ## download data
+      content <- xGET(path,
+                      args,
+                      file = file_path_name,
+                      ...)
+    }
+  } else {
+    ## download without caching
     content <- xGET(path,
                     args,
-                    file = file_path_name,
+                    file = NULL,
                     ...)
   }
+
   if (!isTRUE(tidy)) {
     return(content)
   } else{
