@@ -1,4 +1,5 @@
 test_that("plans works", {
+  plans_cache$delete_all()
   vcr::use_cassette("plans_works", {
     x <- plans(huc ="020700100103")
   })
@@ -15,6 +16,7 @@ test_that("plans works", {
   testthat::expect_s3_class(x$associated_pollutants, "tbl_df")
   testthat::expect_s3_class(x$associated_parameters, "tbl_df")
 
+  skip_on_cran()
   x <- plans(huc = "020700100103", tidy = FALSE)
   testthat::expect_type(x, "character")
 })
